#
# spec file for package audit-secondary
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without python2
%bcond_without python3
# This package contains all audit functionality except for audit-libs.
# The seperation is required to minimize unnecessary build cycles.
%define 	_name audit
Name:           audit-secondary
Version:        3.0.6
Release:        150400.4.16.1
Summary:        Linux kernel audit subsystem utilities
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://people.redhat.com/sgrubb/audit/
Source0:        https://people.redhat.com/sgrubb/audit/%{_name}-%{version}.tar.gz
Source1:        system-group-audit.conf
Patch1:         audit-plugins-path.patch
Patch2:         audit-no-gss.patch
Patch3:         audit-allow-manual-stop.patch
Patch4:         audit-ausearch-do-not-require-tclass.patch
Patch5:         change-default-log_group.patch
Patch6:         libev-werror.patch
Patch7:         harden_auditd.service.patch
Patch8:         change-default-log_format.patch
Patch9:         fix-hardened-service.patch
Patch10:        enable-stop-rules.patch
Patch11:        create-augenrules-service.patch
Patch12:        audit-userspace-517-compat.patch
Patch13:        audisp-remote-fix-hang-with-disk_low_action-suspend-.patch
Patch14:        libaudit-fix-unhandled-ECONNREFUSED-from-getpwnam-25.patch
Patch15:	check-for-AF_UNIX-unnamed-sockets.patch
Patch16:	dependancy-between-augenrules-and-auditd.patch
Patch17:	auditd.service-fix-plugin-termination.patch
BuildRequires:  audit-devel = %{version}
BuildRequires:  autoconf >= 2.12
BuildRequires:  kernel-headers >= 2.6.30
BuildRequires:  libtool
BuildRequires:  openldap2-devel
BuildRequires:  pkgconfig
%if %{with python2}
BuildRequires:  python2-devel
%endif
%if %{with python3}
BuildRequires:  python3-devel
%endif
BuildRequires:  swig
BuildRequires:  systemd-rpm-macros
BuildRequires:  sysuser-tools
BuildRequires:  tcpd-devel
BuildRequires:  pkgconfig(libcap-ng)
Provides:       bundled(libev) = 4.33

%description
The audit package contains the user space utilities for storing and
processing the records generated by the audit subsystem in the
Linux kernel.

%package -n audit
Summary:        User Space Tools for Kernel Auditing
License:        LGPL-2.1-or-later
Group:          System/Monitoring
Requires:       %{_name}-libs = %{version}
Requires:       coreutils
Requires:       group(audit)
%{?systemd_ordering}

%description -n audit
The audit package contains the user space utilities for storing and
processing the audit records generated by the audit subsystem in the
Linux kernel.

%package -n     system-group-audit
Summary:        System group 'audit'
License:        LGPL-2.1-or-later
Group:          System/Fhs
%sysusers_requires

%description -n system-group-audit
This package contains the system group 'audit' for read access to logs.

%package -n     python2-audit
Summary:        Python Bindings for libaudit
License:        LGPL-2.1-or-later
Group:          Development/Languages/Python
Provides:       audit-libs-python = %{version}
Obsoletes:      audit-libs-python < %{version}

%description -n python2-audit
The audit-libs-python package contains the bindings for using libaudit
by python.

%package -n python3-audit
Summary:        Python3 Bindings for libaudit
License:        LGPL-2.1-or-later
Group:          Development/Languages/Python
Provides:       audit-libs-python3 = %{version}
Obsoletes:      audit-libs-python3 < %{version}

%description -n python3-audit
The audit-libs-python3 package contains the bindings for using libaudit
by python3.

%package -n audit-audispd-plugins
Summary:        Default plugins for the audit dispatcher
License:        GPL-2.0-or-later
Group:          System/Monitoring

%description -n audit-audispd-plugins
The audit-audispd-plugins package contains plugin components for the
audit dispatcher (audispd).

%prep
# remove selinux policy
rm -rf audisp/plugins/zos-remote/policy
# we don't build prelude
rm -rf audisp/plugins/prelude
%autosetup -p1 -n %{_name}-%{version}

%if %{without python2} && %{with python3}
# Fix python env call in tests if we only have Python3.
# If both versions are present, python2 bindings are preferred by the tests and
# unconditionally using /usr/bin/python3 breaks the tests
# Probably the correct solution is to run the tests twice if both are present.
perl -i -lpe 's{#!/usr/bin/env python\S+}{#!/usr/bin/python3}' auparse/test/auparse_test.py
%endif

%build
autoreconf -fi
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"
export LDFLAGS="-Wl,-z,relro,-z,now"
# no krb support (omit --enable-gssapi-krb5=yes), see audit-no-gss.patch
%configure \
%ifarch aarch64
	--with-aarch64 \
%endif
	--enable-systemd \
	--libexecdir=%{_libexecdir}/%{_name} \
	--with-apparmor \
	--with-libwrap \
	--with-libcap-ng=yes \
	--disable-static \
	%{?_with_python3} \
	%{?_without_python}

%make_build

%sysusers_generate_pre %{SOURCE1} audit system-group-audit.conf

%install
%make_install

mkdir -p %{buildroot}%{_localstatedir}/log/audit/
touch %{buildroot}%{_localstatedir}/log/audit/audit.log
mkdir -p %{buildroot}%{_localstatedir}/spool/audit/
mkdir -p %{buildroot}%{_sysusersdir}
install -m 0644 %{SOURCE1} %{buildroot}%{_sysusersdir}/
# For ghost below, so that old location files will still be there when
# post copy runs
mkdir -p %{buildroot}%{_sysconfdir}/%{_name}/
mkdir -p %{buildroot}%{_sysconfdir}/%{_name}/rules.d/
touch %{buildroot}%{_sysconfdir}/{auditd.conf,audit.rules} %{buildroot}%{_sysconfdir}/audit/auditd.conf
# On platforms with 32 & 64 bit libs, we need to coordinate the timestamp
touch -r ./audit.spec %{buildroot}%{_sysconfdir}/libaudit.conf
# Starting with audit 2.5 no config is installed so start with no rules
install -m 0644 rules/10-no-audit.rules %{buildroot}%{_sysconfdir}/%{_name}/rules.d/audit.rules
# delete redhat scripts, use ours
rm -rf %{buildroot}%{_sysconfdir}/sysconfig/auditd
rm -rf %{buildroot}%{_initddir}/auditd
rm -rf %{buildroot}%{_sysconfdir}/rc.d/init.d
# delete redhat systemd legacy scripts, our systemd doesn't support the feature
# https://lists.fedoraproject.org/pipermail/devel/2012-June/169411.html
rm -rf %{buildroot}%{_libexecdir}/audit
# Clean up some unneeded library files
rm -f %{buildroot}/%{_libdir}/python*/site-packages/{_audit,_auparse,auparse}.{a,la}
rm -rf %{buildroot}/%{_libdir}/python*/site-packages/__pycache__
# cleanup makefiles for the rules (installed by %%docs command)
rm -f %{buildroot}/%{_libdir}/pkgconfig/{audit,auparse}.pc
# cleanup files handled by audit.spec
rm -rf %{buildroot}/%{_datadir}/aclocal/
rm -rf %{buildroot}/%{_includedir}
rm -f %{buildroot}/%{_libdir}/lib{audit,auparse}.*
rm -f %{buildroot}%{_sysconfdir}/libaudit.conf
rm -f %{buildroot}/%{_mandir}/man5/libaudit.conf.5
rm -rf %{buildroot}/%{_mandir}/man3
# Cleanup plugins
#USR-MERGE
%if !0%{?usrmerged}
mkdir %{buildroot}/sbin/
for prog in auditctl auditd ausearch autrace aureport augenrules audisp-syslog; do
  ln -s %{_sbindir}/$prog %{buildroot}/sbin/$prog
done
%endif
#END-USR-MERGE
# rcauditd symlink
ln -s service %{buildroot}%{_sbindir}/rcauditd
chmod 0644 %{buildroot}%{_unitdir}/auditd.service
chmod 0644 %{buildroot}%{_unitdir}/augenrules.service

%check
%make_build check

%post -n audit
# Save existing audit files if any (from old locations)
if [ -f %{_sysconfdir}/auditd.conf ]; then
   mv %{_sysconfdir}/audit/auditd.conf %{_sysconfdir}/audit/auditd.conf.new
   mv %{_sysconfdir}/auditd.conf %{_sysconfdir}/audit/auditd.conf
fi
if [ -f %{_sysconfdir}/audit.rules ]; then
   mv %{_sysconfdir}/audit.rules %{_sysconfdir}/audit/audit.rules
elif [ ! -f %{_sysconfdir}/audit/audit.rules ]; then
   cp %{_sysconfdir}/audit/rules.d/audit.rules %{_sysconfdir}/audit/audit.rules
fi
%service_add_post auditd.service
%service_add_post augenrules.service

%pre -n audit
%service_add_pre auditd.service
%service_add_pre augenrules.service

%pre -n system-group-audit -f audit.pre

%preun -n audit
%service_del_preun auditd.service
%service_del_preun augenrules.service

%postun -n audit
%service_del_postun auditd.service
%service_del_postun augenrules.service

%files -n audit
%license COPYING
%doc README ChangeLog init.d/auditd.cron
%attr(644,root,root) %{_mandir}/man8/auditctl.8.gz
%attr(644,root,root) %{_mandir}/man8/auditd.8.gz
%attr(644,root,root) %{_mandir}/man8/aureport.8.gz
%attr(644,root,root) %{_mandir}/man8/ausearch.8.gz
%attr(644,root,root) %{_mandir}/man8/autrace.8.gz
%attr(644,root,root) %{_mandir}/man8/aulast.8.gz
%attr(644,root,root) %{_mandir}/man8/aulastlog.8.gz
%attr(644,root,root) %{_mandir}/man8/ausyscall.8.gz
%attr(644,root,root) %{_mandir}/man7/audit.rules.7.gz
%attr(644,root,root) %{_mandir}/man5/auditd.conf.5.gz
%attr(644,root,root) %{_mandir}/man5/ausearch-expression.5.gz
%attr(644,root,root) %{_mandir}/man8/auvirt.8.gz
%attr(644,root,root) %{_mandir}/man8/augenrules.8.gz
%if !0%{?usrmerged}
/sbin/auditctl
/sbin/auditd
/sbin/ausearch
/sbin/autrace
/sbin/augenrules
/sbin/aureport
/sbin/audisp-syslog
%endif
%attr(750,root,root) %{_sbindir}/auditctl
%attr(750,root,root) %{_sbindir}/auditd
%attr(755,root,root) %{_sbindir}/ausearch
%attr(750,root,root) %{_sbindir}/autrace
%attr(750,root,root) %{_sbindir}/augenrules
%attr(750,root,root) %{_sbindir}/audisp-syslog
%attr(755,root,root) %{_bindir}/aulast
%attr(755,root,root) %{_bindir}/aulastlog
%attr(755,root,root) %{_bindir}/ausyscall
%attr(755,root,root) %{_sbindir}/aureport
%attr(755,root,root) %{_bindir}/auvirt
%dir %attr(750,root,root) %{_sysconfdir}/audit
%attr(750,root,root) %dir %{_sysconfdir}/audit/plugins.d
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/plugins.d/af_unix.conf
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/plugins.d/syslog.conf
%ghost %{_sysconfdir}/auditd.conf
%ghost %{_sysconfdir}/audit.rules
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/auditd.conf
%dir %attr(750,root,root) %{_sysconfdir}/audit/rules.d
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/rules.d/audit.rules
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/audit-stop.rules
%dir %attr(750,root,audit) %{_localstatedir}/log/audit
%ghost %config(noreplace) %attr(640,root,audit) %{_localstatedir}/log/audit/audit.log
%dir %attr(700,root,root) %{_localstatedir}/spool/audit
%{_unitdir}/auditd.service
%{_unitdir}/augenrules.service
%{_sbindir}/rcauditd
%{_datadir}/audit/

%files -n system-group-audit
%{_sysusersdir}/system-group-audit.conf

%if %{with python2}
%files -n python2-audit
%attr(755,root,root) %{python2_sitearch}/_audit.so
%attr(755,root,root) %{python2_sitearch}/auparse.so
%{python2_sitearch}/audit.py*
%endif

%if %{with python3}
%files -n python3-audit
%attr(755,root,root) %{python3_sitearch}/*
%endif

%files -n audit-audispd-plugins
%attr(644,root,root) %{_mandir}/man8/audispd-zos-remote.8.gz
%attr(644,root,root) %{_mandir}/man5/zos-remote.conf.5.gz
%attr(644,root,root) %{_mandir}/man5/audisp-remote.conf.5.gz
%attr(644,root,root) %{_mandir}/man5/auditd-plugins.5.gz
%attr(644,root,root) %{_mandir}/man8/audisp-remote.8.gz
%attr(644,root,root) %{_mandir}/man8/audisp-syslog.8.gz
%attr(750,root,root) %dir %{_sysconfdir}/audit
%attr(750,root,root) %dir %{_sysconfdir}/audit/plugins.d
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/plugins.d/audispd-zos-remote.conf
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/zos-remote.conf
%attr(750,root,root) %{_sbindir}/audisp-remote
%attr(750,root,root) %{_sbindir}/audispd-zos-remote
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/audisp-remote.conf
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/plugins.d/au-remote.conf

%changelog
* Thu Feb  1 2024 ematsumiya@suse.de
- Fix plugin termination when using systemd service units (bsc#1215377)
  * add auditd.service-fix-plugin-termination.patch
* Tue Aug 15 2023 ematsumiya@suse.de
- Update audit-secondary.spec: create symbolic link from
  /sbin/audisp-syslog to /usr/sbin/audisp-syslog (bsc#1201519).
* Tue Aug 15 2023 ematsumiya@suse.de
- Fix rules not loaded when restarting auditd.service(bsc#1204844)
* Wed Jun  7 2023 ematsumiya@suse.de
- Check for AF_UNIX unnamed sockets (bsc#1210004)
  * add check-for-AF_UNIX-unnamed-sockets.patch
* Mon Apr 11 2022 jengelh@inai.de
- Drop buildrequire on C++ compiler.
- Modernize specfile constructs.
* Sat Mar 26 2022 coolo@suse.com
- Fix buildrequire for openldap2-devel - audit doesn't require the
  (outdated) C++ binding, but the C headers that happen to be pulled
  in by buildrequiring the C++ devel package
* Fri Mar 25 2022 ematsumiya@suse.com
- Fix unhandled ECONNREFUSED with LDAP environments (bsc#1196645)
  * add libaudit-fix-unhandled-ECONNREFUSED-from-getpwnam-25.patch
- Fix hang in audisp-remote with disk_low_action=suspend (bsc#1196517)
  * add audisp-remote-fix-hang-with-disk_low_action-suspend-.patch
* Wed Mar 23 2022 dmueller@suse.com
- add audit-userspace-517-compat.patch
* Mon Nov 29 2021 fvogt@suse.com
- Use %%autosetup
- Don't include sample rules as %%doc, they're already installed
  as normal files
- Fix create-augenrules-service.patch:
  * auditd.service needs to require augenrules.service,
    not the other way around
- Fix documentation for enable-stop-rules.patch
* Sun Nov  7 2021 gmbr3@opensuse.org
- Update to version 3.0.6:
  * fixes a segfault on some SELINUX_ERR records
  * makes IPX packet interpretation dependent on the ipx header
    file existing
  * adds b32/b64 support to ausyscall
  * adds support for armv8l
  * fixes auditctl list of syscalls on PPC
  * auditd.service now restarts auditd under some conditions
* Fri Oct 15 2021 gmbr3@opensuse.org
- Add CONFIG parameter to %%sysusers_generate_pre
* Wed Oct 13 2021 ematsumiya@suse.com
- Create separate service for augenrules (bsc#1191614, bsc#1181400)
  * add create-augenrules-service.patch
  Remove ReadWritePaths=/etc/audit from auditd.service, also removes
  augenrules call from ExecStartPost.
  Create augenrules.service with the ReadWritePaths directive above.
  This makes /etc/audit only accessible by augenrules.service and
  let auditd.service (and daemon) to be sandboxed again.
- Update audit-secondary.spec to accomodate the new service file.
* Mon Sep 20 2021 ematsumiya@suse.com
- Fix hardened auditd.service (bsc#1181400)
  * add fix-hardened-service.patch
    Make /etc/audit read-write from the service.
    Remove PrivateDevices=true to expose /dev/* to auditd.service.
- Enable stop rules for audit.service (cf. bsc#1190227)
  * add enable-stop-rules.patch
* Thu Sep 16 2021 ematsumiya@suse.com
- Change default log_format from ENRICHED to RAW (bsc#1190500):
  * add change-default-log_format.patch (SUSE-specific patch)
- Update to version 3.0.5:
  * In auditd, flush uid/gid caches when user/group added/deleted/modified
  * Fixed various issues when dealing with corrupted logs
  * In auditd, check if log_file is valid before closing handle
- Include fixed from 3.0.4:
  * Apply performance speedups to auparse library
  * Optimize rule loading in auditctl
  * Fix an auparse memory leak caused by glibc-2.33 by replacing realpath
  * Update syscall table to the 5.14 kernel
  * Fixed various issues when dealing with corrupted logs
* Mon Aug 16 2021 meissner@suse.com
- harden_auditd.service.patch: automatic hardening applied to systemd
  services
* Fri Jul 30 2021 ematsumiya@suse.com
- Update to version 3.0.3:
  * Dont interpret audit netlink groups unless AUDIT_NLGRP_MAX is defined
  * Add support for AUDIT_RESP_ORIGIN_UNBLOCK_TIMED to ids
  * Change auparse_feed_has_data in auparse to include incomplete events
  * Auditd, stop linking against -lrt
  * Add ProtectHome and RestrictRealtime to auditd.service
  * In auditd, read up to 3 netlink packets in a row
  * In auditd, do not validate path to plugin unless active
  * In auparse, only emit config errors when AUPARSE_DEBUG env variable exists
- use https source urls
* Mon Jun 14 2021 ematsumiya@suse.com
- Adjust audit.spec and audit-secondary.spec to support new version
- Include fix for libev
  * add libev-werror.patch
- Update to version 3.0.2
- In audispd-statsd pluging, use struct sockaddr_storage (Ville Heikkinen)
- Optionally interpret auid in auditctl -l
- Update some syscall argument interpretations
- In auditd, do not allow spaces in the hostname name format
- Big documentation cleanup (MIZUTA Takeshi)
- Update syscall table to the 5.12 kernel
- Update the auparse normalizer for new event types
- Fix compiler warnings in ids subsystem
- Block a couple signals from flush & reconfigure threads
- In auditd, don't wait on flush thread when exiting
- Output error message if the path of input files are too long ausearch/report
  Included fixes from 3.0.1
- Update syscall table to the 5.11 kernel
- Add new --eoe-timeout option to ausearch and aureport (Burn Alting)
- Only enable periodic timers when listening on the network
- Upgrade libev to 4.33
- Add auparse_new_buffer function to auparse library
- Use the select libev backend unless aggregating events
- Add sudoers to some base audit rules
- Update the auparse normalizer for some new syscalls and event types
  Included fixes from 3.0
- Generate checkpoint file even when no results are returned (Burn Alting)
- Fix log file creation when file logging is disabled entirely (Vlad Glagolev)
- Convert auparse_test to run with python3 (Tomáš Chvátal)
- Drop support for prelude
- Adjust backlog_wait_time in rules to the kernel default (#1482848)
- Remove ids key syntax checking of rules in auditctl
- Use SIGCONT to dump auditd internal state (#1504251)
- Fix parsing of virtual timestamp fields in ausearch_expression (#1515903)
- Fix parsing of uid & success for ausearch
- Add support for not equal operator in audit by executable (Ondrej Mosnacek)
- Hide lru symbols in auparse
- Add systemd process protections
- Fix aureport summary time range reporting
- Allow unlimited retries on startup for remote logging
- Add queue_depth to remote logging stats and increase default queue_depth size
- Fix segfault on shutdown
- Merge auditd and audispd code
- Close on execute init_pipe fd (#1587995)
- Breakout audisp syslog plugin to be standalone program
- Create a common internal library to reduce code
- Move all audispd config files under /etc/audit/
- Move audispd.conf settings into auditd.conf
- Add queue depth statistics to internal state dump report
- Add network statistics to internal state dump report
- SIGUSR now also restarts queue processing if its suspended
- Update lookup tables for the 4.18 kernel
- Add auparse_normalizer support for SOFTWARE_UPDATE event
- Add 30-ospp-v42.rules to meet new Common Criteria requirements
- Deprecate enable_krb and replace with transport config opt for remote logging
- Mark netlabel events as simple events so that get processed quicker
- When auditd is reconfiguring, only SIGHUP plugins with valid pid (#1614833)
- In aureport, fix segfault in file report
- Add auparse_normalizer support for labeled networking events
- Fix memory leak in audisp-remote plugin when using krb5 transport. (#1622194)
- In ausearch/auparse, event aging is off by a second
- In ausearch/auparse, correct event ordering to process oldest first
- Migrate auparse python test to python3
- auparse_reset was not clearing everything it should
- Add support for AUDIT_MAC_CALIPSO_ADD, AUDIT_MAC_CALIPSO_DEL events
- In ausearch/report, lightly parse selinux portion of USER_AVC events
- Add bpf syscall command argument interpretation to auparse
- In ausearch/report, limit record size when malformed
- Port af_unix plugin to libev
- In auditd, fix extract_type function for network originating events
- In auditd, calculate right size and location for network originating events
- Make legacy script wait for auditd to terminate (#1643567)
- Treat all network originating events as VER2 so dispatcher doesn't format it
- If an event has a node name make it VER2 so dispatcher doesnt format it
- In audisp-remote do an initial connection attempt (#1625156)
- In auditd, allow expression of space left as a percentage (#1650670)
- On PPC64LE systems, only allow 64 bit rules (#1462178)
- Make some parts of auditd state report optional based on config
- Update to libev-4.25
- Fix ausearch when checkpointing a single file (Burn Alting)
- Fix scripting in 31-privileged.rules wrt filecap (#1662516)
- In ausearch, do not checkpt if stdin is input source
- In libev, remove __cold__ attribute for functions to allow proper hardening
- Add tests to configure.ac for openldap support
- Make systemd support files use /run rather than /var/run (Christian Hesse)
- Fix minor memory leak in auditd kerberos credentials code
- Allow exclude and user filter by executable name (Ondrej Mosnacek)
- Fix auditd regression where keep_logs is limited by rotate_logs 2 file test
- In ausearch/report fix --end to use midnight time instead of now (#1671338)
- Add substitue functions for strndupa & rawmemchr
- Fix memleak in auparse caused by corrected event ordering
- Fix legacy reload script to reload audit rules when daemon is reloaded
- Support for unescaping in trusted messages (Dmitry Voronin)
- In auditd, use standard template for DEAMON events (Richard Guy Briggs)
- In aureport, fix segfault for malformed USER_CMD events
- Add exe field to audit_log_user_command in libaudit
- In auditctl support filter on socket address families (Richard Guy Briggs)
- Deprecate support for Alpha & IA64 processors
- If space_left_action is rotate, allow it every time (#1718444)
- In auparse, drop standalone EOE events
- Add milliseconds column for ausearch extra time csv format
- Fix aureport first event reporting when no start given
- In audisp-remote, add new config item for startup connection errors
- Remove dependency on chkconfig
- Install rules to /usr/share/audit/sample-rules/
- Split up ospp rules to make SCAP scanning easier (#1746018)
- In audisp-syslog, support interpreting records (#1497279)
- Audit USER events now sends msg as name value pair
- Add support for AUDIT_BPF event
- Auditd should not process AUDIT_REPLACE events
- Update syscall tables to the 5.5 kernel
- Improve personality interpretation by using PERS_MASK
- Speedup ausearch/report parsing RAW logging format by caching uid/name lookup
- Change auparse python bindings to shared object (Issue #121)
- Add error messages for watch permissions
- If audit rules file doesn't exist log error message instead of info message
- Revise error message for unmatched options in auditctl
- In audisp-remote, fixup remote endpoint disappearin in ascii format
- Add backlog_wait_time_actual reporting / resetting to auditctl (Max Englander)
- In auditctl, add support for sending a signal to auditd
- Removes audit-fno-common.patch: fixed in upstream
- Removes audit-python3.patch: fixed in upstream
* Mon Feb  1 2021 dimstar@opensuse.org
- Do not explicitly provide group(audit) in system-users-audit:
  this is automatically handled by rpm/providers.
* Thu Jan 28 2021 ematsumiya@suse.com
- Create new "audit" group for read access to logs (bsc#1178154)
  * add change-default-log_group.patch
  * update audit-secondary.spec
* Wed Dec  2 2020 abergmann@suse.com
- Enable Aarch64 processor support. (bsc#1179515 bsc#1179806)
* Fri Oct 16 2020 lnussel@suse.de
- prepare usrmerge (boo#1029961)
* Mon Jan 13 2020 tonyj@suse.com
- Update to version 2.8.5:
  * Fix segfault on shutdown
  * Fix hang on startup (#1587995)
  * Add sleep to script to dump state so file is ready when needed
  * Add auparse_normalizer support for SOFTWARE_UPDATE event
  * Mark netlabel events as simple events so that get processed quicker
  * When audispd is reconfiguring, only SIGHUP plugins with valid pid (#1614833)
  * Add 30-ospp-v42.rules to meet new Common Criteria requirements
  * Update lookup tables for the 4.18 kernel
  * In aureport, fix segfault in file report
  * Add auparse_normalizer support for labeled networking events
  * Fix memory leak in audisp-remote plugin when using krb5 transport. (#1622194)
  * Event aging is off by a second
  * In ausearch/auparse, correct event ordering to process oldest first
  * auparse_reset was not clearing everything it should
  * Add support for AUDIT_MAC_CALIPSO_ADD, AUDIT_MAC_CALIPSO_DEL events
  * In ausearch/report, lightly parse selinux portion of USER_AVC events
  * In ausearch/report, limit record size when malformed
  * In auditd, fix extract_type function for network originating events
  * In auditd, calculate right size and location for network originating events
  * Treat all network originating events as VER2 so dispatcher doesn't format it
  * In audisp-remote do an initial connection attempt (#1625156)
  * In auditd, allow expression of space left as a percentage (#1650670)
  * On PPC64LE systems, only allow 64 bit rules (#1462178)
  * Make some parts of auditd state report optional based on config
  * Fix ausearch when checkpointing a single file (Burn Alting)
  * Fix scripting in 31-privileged.rules wrt filecap (#1662516)
  * In ausearch, do not checkpt if stdin is input source
  * In libev, remove __cold__ attribute for functions to allow proper hardening
  * Add tests to configure.ac for openldap support
  * Make systemd support files use /run rather than /var/run (Christian Hesse)
  * Fix minor memory leak in auditd kerberos credentials code
  * Fix auditd regression where keep_logs is limited by rotate_logs 2 file test
  * In ausearch/report fix --end to use midnight time instead of now (#1671338)
- Fix build errors when using gcc-10 no-common default (bsc#1160384)
  New patch: audit-fno-common.patch
- Refresh audit-allow-manual-stop.patch
* Thu Mar 21 2019 jengelh@inai.de
- Reduce scriptlets' hard dependency on systemd.
* Sat Jun 23 2018 antoine.belvire@opensuse.org
- Update to version 2.8.4:
  * Generate checkpoint file even when not results are returned
    (Burn Alting).
  * Fix log file creation when file logging is disabled entirely
    (Vlad Glagolev).
  * Use SIGCONT to dump auditd internal state (rh#1504251).
  * Fix parsing of virtual timestamp fields in ausearch_expression
    (rh#1515903).
  * Fix parsing of uid & success for ausearch.
  * Hide lru symbols in auparse.
  * Fix aureport summary time range reporting.
  * Allow unlimited retries on startup for remote logging.
  * Add queue_depth to remote logging stats and increase default
    queue_depth size.
* Sun Jun 17 2018 antoine.belvire@opensuse.org
- Update to version 2.8.3:
  * Correct msg function name in lru debug code.
  * Fix a segfault in auditd when dns resolution isn't available.
  * Make a reload legacy service for auditd.
  * In auparse python bindings, expose some new types that were
    missing.
  * In normalizer, pickup subject kind for user_login events.
  * Fix interpretation of unknown ioctcmds (rh#1540507).
  * Add ANOM_LOGIN_SERVICE, RESP_ORIGIN_BLOCK, &
    RESP_ORIGIN_BLOCK_TIMED events.
  * In auparse_normalize for USER_LOGIN events, map acct for
    subj_kind.
  * Fix logging of IPv6 addresses in DAEMON_ACCEPT events
    (rh#1534748).
  * Do not rotate auditd logs when num_logs < 2 (brozs).
* Tue Apr  3 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Fri Mar 16 2018 tonyj@suse.com
- Change openldap dependency to client only (bsc#1085003)
- Resolve issue with previous change if both Python2 and Python3 are
  present, tests were failing as python2 bindings are preferred in this
  case.
* Thu Feb 22 2018 meissner@suse.com
- reverted -j1 force ppc specific only
* Wed Feb  7 2018 tchvatal@suse.com
- Add patch to fix test run without python2 interpreter:
  * audit-python3.patch
- Update to 2.8.2 release:
  * Update tables for 4.14 kernel
  * Fixup ipv6 server side binding
  * AVC report from aureport was missing result column header (#1511606)
  * Add SOFTWARE_UPDATE event
  * In ausearch/report pickup any path and new-disk fields as a file
  * Fix value returned by auditctl --reset-lost (Richard Guy Briggs)
  * In auparse, fix expr_create_timestamp_comparison_ex to be numeric field
  * Fix building on old systems without linux/fanotify.h
  * Fix shell portability issues reported by shellcheck
  * Auditd validate_email should not use gethostbyname
* Tue Feb  6 2018 normand@linux.vnet.ibm.com
- force -j1 for PowerPC make check to avoid build failure
  (lookup_test.o: file not recognized: File truncated)
* Wed Jan 17 2018 tchvatal@suse.com
- Add conditions around python plugins to allow us to conditionalize
  them in enviroment without python2
* Thu Nov  9 2017 mpluskal@suse.com
- Rename python binding packages to match current python packaging
  standards
- Update python build dependencies to resolve future split of
  python2/3
* Sat Nov  4 2017 aavindraa@gmail.com
- Update to version 2.8.1. See audit.spec (libaudit1) for upstream
  changelog
- Remove audit-implicit-writev.patch (fixed upstream across 2
  commits)
  * 3b30db20ad983274989ce9a522120c3c225436b3
  * 07132c22314e9abbe64d1031fd8734243285bb3f
- Cleanup with spec-cleaner
* Fri Aug 18 2017 dimstar@opensuse.org
- Add audit-implicit-writev.patch: include sys/uio.h to ensure
  readv and writev are declared.
* Mon Jul 24 2017 jengelh@inai.de
- Rectify RPM groups, diversify descriptions.
- Remove mentions of static libraries because they are not built.
* Tue Jul 18 2017 tonyj@suse.com
- Update to version 2.7.7. See audit.spec (libaudit1) for upstream
  changelog
  Since commit 6cf57d27 (2.7.4) audit is now started as an non-forking
  service (bsc#1042781).
  Add config: audit-stop.rules
  Refresh patch: audit-allow-manual-stop.patch
  Refresh patch: audit-no-gss.patch
* Fri Apr  1 2016 tchvatal@suse.com
- Version update to 2.5. See audit.spec (libaudit1) for upstream
  changelog
- Cleanup with spec-cleaner
- Sort out bit /sbin /usr/sbin/ installation
- Install the rules as documentation
- Remove needless %%py_requires from python subpkgs
* Fri Aug 21 2015 tonyj@suse.com
- Update to version 2.4.4. See audit.spec (libaudit1) for upstream
  changelog
- Add python3 bindings for libaudit and libauparse
- Remove patch 'audit-no_m4_dir.patch'
  (added Fri Apr 26 11:14:39 UTC 2013 by mmeister@suse.com)
  No idea what earlier 'automake' build error this was trying to fix but
  it broke the handling of "--without-libcap-ng". Anyways, no build error
  occurs now and m4 path is also needed in v2.4.4 to find ax_prog_cc_for_build
* Tue Sep  2 2014 tonyj@suse.com
- Update to version 2.4. See audit.spec (libaudit1) for upstream
  changelog
  Drop patch: auditd-donot-start-if-kernel-cmdline-disabled.patch
* Fri Aug 15 2014 crrodriguez@opensuse.org
- If the system has been booted with audit=0 in the kernel cmdline
  auditd.service must refrain from starting as the relevant kernel
  subsystem will be permanently disabled.
  add patch: auditd-donot-start-if-kernel-cmdline-disabled.patch
* Thu Jul 10 2014 tonyj@suse.com
- Do not require tclass field to be present when searching for AVC
  records (bnc#878687)
  add patch: audit-ausearch-do-not-require-tclass.patch
* Tue Apr 15 2014 tonyj@suse.com
- Update to version 2.3.6. See audit.spec (libaudit1) for upstream
  changelog
* Wed Mar 26 2014 crrodriguez@opensuse.org
- fix systemd warning:
  "Configuration file /usr/lib/systemd/system/auditd.service
  is marked world-inaccessible.
  This has no effect as configuration data is accessible
  via APIs without restrictions"
  * indeed restricting access to unit files using filesystem
  permissions is non-sense.
* Thu Feb 27 2014 tonyj@suse.com
- Add systemd requires (bnc#865849)
* Tue Feb  4 2014 tonyj@suse.com
- Update to version 2.3.3. See audit.spec (libaudit1) for upstream
  changelog
* Tue Nov 26 2013 tonyj@suse.com
- Update to version 2.3.2. See audit.spec (libaudit1) for upstream
  changelog
- Drop patch 'audit-fix-implicit-defn.patch' (upstream)
- Add patch 'audit-allow-manual-stop.patch' to reinstate service
  stop/restart.
- /etc/sysconfig/audit still existed but was no longer referenced
  by systemd, so remove
- Delete audit-no_plugins.patch, it was stale (no longer referenced
  by specfiles) but had not been removed.
* Wed Oct  2 2013 opensuse@cboltz.de
- (re-)add rcauditd as symlink to /usr/sbin/service
* Thu Jun 27 2013 tonyj@suse.com
- Eliminate build cycles. audit.spec now builds only libs/devel.
  Remainder (including daemon) built from audit-secondary.spec
- Add patch 'audit-fix-implicit-defn.patch' to fix implicit definition
  warning.
* Mon Mar 25 2013 crrodriguez@opensuse.org
- Buildrequires cap-ng library
* Tue Jan 22 2013 jengelh@inai.de
- Executing autoreconf requires autoconf
* Fri Oct 12 2012 coolo@suse.com
- Update to version 2.2.1, see audit's changes
* Tue Feb 28 2012 tonyj@suse.com
- Update to version 2.1.3.  See audit.spec upstream changelog
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri May 20 2011 tonyj@novell.com
- Adjust license of audit-libs-python to be LGPLv2.1 or later.
* Wed Apr 27 2011 tonyj@novell.com
- Upgrade to version 2.1.1 (see audit.changes for upstream change
  history)
* Wed Sep 29 2010 tonyj@novell.com
- Upgrade to version 2.0.5 (see audit.changes for upstream change
  history)
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Tue May  4 2010 tonyj@suse.de
- Upgrade to version 2.0.4 (see audit.changes for upstream change
  history)
* Sat Jun 20 2009 cmorve69@yahoo.es
- fixed build with --as-needed
* Mon May 11 2009 tonyj@suse.de
- Update from 1.7.7 to 1.7.13 (see audit.changes for upstream change
  history)
* Fri Sep 26 2008 tonyj@suse.de
- Update from 1.7.4 to 1.7.7 (see audit.changes for upstream change
  history)
* Fri Aug  1 2008 ro@suse.de
- disable debuginfo for secondary specfile
* Tue Jun 24 2008 tonyj@suse.de
- Update from 1.7.2 to 1.7.4 (see audit.changes for upstream change
  history)
- Update from 1.6.8 to 1.7.2 (see audit.changes for upstream change
  history)
* Tue Jun  3 2008 coolo@suse.de
- avoid packaging a directory with different permissions (creating
  rpm -V output)
* Wed Apr 16 2008 aj@suse.de
- Use %%py_requires for proper requires.
* Wed Mar 26 2008 tonyj@suse.de
- Update to version 1.6.8.
- Rename to audit-secondary and build audisp-plugins from here
  to minimise bootstrap dependancies.
* Tue Mar 18 2008 schwab@suse.de
- Use autoreconf.
* Wed Oct 10 2007 tonyj@suse.de
- Upgrade to 1.6.2
* Tue Jul 24 2007 tonyj@suse.de
- Upgrade to 1.5.5
    Drop audit-swig-attribute.patch (upstreamed)
* Thu Jul 12 2007 tonyj@suse.de
- Fix build errors on ppc
* Wed Jul 11 2007 tonyj@suse.de
- Upgrade to 1.5.4
* Wed May  2 2007 tonyj@suse.de
- Upgrade to 1.5.3.
* Wed Nov 29 2006 tonyj@suse.de
- Upgrade to 1.2.9 (drop several patches which are now upstream)
- /usr/sbin/audispd now packaged by audit-libs-python
* Sat Nov  4 2006 ro@suse.de
- fix requires
* Thu Aug 31 2006 tonyj@suse.de
- Upgrade to 1.2.6-1
* Wed Aug 16 2006 cthiel@suse.de
- split off package
